@@ -38,7 +38,7 @@ public:
     void updateXYRange();
 
 public slots:
-    virtual void done(int result) Q_DECL_OVERRIDE;
+    virtual void done(int result) override;
 
 protected slots:
     void updateButtons();
